@@ -52,6 +52,7 @@ from io import open
 from multiprocessing import Pool
 from socket import gethostname
 
+import psutil
 import zmq
 
 from gridmap.conf import (CHECK_FREQUENCY, CREATE_PLOTS, DEFAULT_QUEUE,
@@ -77,6 +78,12 @@ if CREATE_PLOTS:
     import matplotlib.pyplot as plt
 
 
+# Set of "not running" job statuses
+SLEEP_STATUSES = {psutil.STATUS_SLEEPING, psutil.STATUS_DEAD,
+                  psutil.STATUS_IDLE, psutil.STATUS_STOPPED,
+                  psutil.STATUS_ZOMBIE}
+
+
 class JobException(Exception):
     '''
     New exception type for when one of the jobs crashed.
@@ -394,8 +401,8 @@ class JobMonitor(object):
                         logger.error("job died for unknown reason")
                         job.cause_of_death = "unknown"
                     elif (len(job.track_cpu) > MAX_IDLE_HEARTBEATS and
-                          all(cpu_load <= IDLE_THRESHOLD and state == 'S'
-                              for cpu_load, state in
+                          all((cpu_load <= IDLE_THRESHOLD and
+                               state in SLEEP_STATUSES) for cpu_load, state in
                               job.track_cpu[-MAX_IDLE_HEARTBEATS:])):
                         logger.error('Job stalled for unknown reason.')
                         job.cause_of_death = 'stalled'
@@ -417,6 +424,8 @@ class JobMonitor(object):
                 # try to resubmit
                 old_id = job.jobid
                 handle_resubmit(self.session_id, job, temp_dir=self.temp_dir)
+                logging.info('Resubmitted job %s; it now has ID %s', old_id,
+                             job.jobid)
                 if job.jobid is None:
                     logger.error("giving up on job")
                     job.ret = "job dead"
@@ -573,9 +582,9 @@ def handle_resubmit(session_id, job, temp_dir='/scratch/'):
         job.num_resubmits += 1
         job.cause_of_death = ""
 
-        return _resubmit(session_id, job, temp_dir)
+        _resubmit(session_id, job, temp_dir)
     else:
-        return None
+        job.jobid = None
 
 
 def _execute(job):
@@ -701,7 +710,7 @@ def _append_job_to_session(session, job, temp_dir='/scratch/', quiet=True):
 
     if not quiet:
         print('Your job {} has been submitted with id {}'.format(job.name,
-                                                                   jobid),
+                                                                 jobid),
               file=sys.stderr)
 
     session.deleteJobTemplate(jt)
